@@ -4,7 +4,8 @@ from .classes import *
 
 
 class ClientShell:
-    def __init__(self, client, button_first=None, message_first=None, inline_first=None, first_occurrence=True):
+    def __init__(self, client, button_first=None, message_first=None, inline_first=None, first_occurrence=True,
+                 from_me=False):
         self.client = client
         self.message_handlers = []
         self.inline_handlers = []
@@ -13,9 +14,13 @@ class ClientShell:
         self.inline_first = inline_first
         self.button_first = button_first
         self.first_occurrence = first_occurrence
+        self.from_me = from_me
 
         @self.client.on(events.NewMessage())
         async def client_handler(event):
+            if not self.from_me:
+                if event.message.out:
+                    return None
             for f in self.message_handlers:
                 passed = False
                 text = event.text
